getLocations method

Future<List<Location>?> getLocations([
  1. String? locationId
])

The function getLocations returns a future that retrieves a list of locations using the GeofencingFlutterPluginPlatform. @param {String} locationId - The locationId parameter is an optional String that represents the ID of a specific location. If provided, the function will retrieve the location with the matching ID. If not provided, the function will retrieve all locations. @returns a Future object that resolves to a List of Location objects, or null if no locations are found.

Implementation

Future<List<Location>?> getLocations([String? locationId]) {
  return GeofencingFlutterPluginPlatform.instance.getLocations(locationId);
}