GeofenceBackgroundDispatcher class

Runs in the background isolate and forwards region events to the callback registered with GeofencingFlutterPlugin.registerBackgroundRegionCallback.

Constructors

GeofenceBackgroundDispatcher({MethodChannel? channel, CallbackResolver? resolver})
Creates a dispatcher. channel and resolver are only meant to be overridden by tests.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleMethodCall(MethodCall call) → Future<void>
Handles a call coming from the platform side of the background channel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
Listens to the background channel and tells the platform that the isolate is ready to receive region events.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited