start method

Future<void> start()

Listens to the background channel and tells the platform that the isolate is ready to receive region events.

Implementation

Future<void> start() async {
  _channel.setMethodCallHandler(handleMethodCall);
  await _channel.invokeMethod<void>(BackgroundChannel.initialized);
}