GeofenceRegionCallback typedef

GeofenceRegionCallback = FutureOr<void> Function(Region region)

Signature of the Dart function woken by the plugin when a geofence region event is delivered while the application is in the background or has been terminated.

The function must be a top level or a static function annotated with @pragma('vm:entry-point'), otherwise the Dart VM cannot resolve it from the background isolate.

Implementation

typedef GeofenceRegionCallback = FutureOr<void> Function(Region region);