geofencingCallbackDispatcher function

void geofencingCallbackDispatcher()

Entry point executed by the platform in a background isolate when a region event is received while no Flutter engine of the application is running.

Implementation

@pragma('vm:entry-point')
void geofencingCallbackDispatcher() {
  WidgetsFlutterBinding.ensureInitialized();
  unawaited(GeofenceBackgroundDispatcher().start());
}