WoosmapGeofencingOptions class

Options used to configure the Woosmap Geofencing Plugin.

Constructors

WoosmapGeofencingOptions({String? privateKeyWoosmapAPI, TrackingProfile? trackingProfile, bool? enableAirshipConnector, int? protectedRegionSlot, String? androidNotificationText, String? androidNotificationTitle, String? androidNotificationIconName, String? androidNotificationIconUrl})
Constructor to create a configuration object for geofencing initialization.

Properties

androidNotificationIconName → String?
Android notification icon that appears in liveTracking and optimalLiveTracking. This icon should be present as the android drawable or mipmap resource.
final
androidNotificationIconUrl → String?
Android notification icon that appears in liveTracking and optimalLiveTracking. This icon should be present in the flutter assets folder.
final
androidNotificationText → String?
Android notification text that appears in liveTracking and optimalLiveTracking.
final
androidNotificationTitle → String?
Android notification title that appears in liveTracking and optimalLiveTracking.
final
enableAirshipConnector → bool?
Whether to enable the integration with the Airship connector.
final
hashCode → int
The hash code for this object.
no setterinherited
privateKeyWoosmapAPI → String?
Your private API key for accessing the Woosmap API.
final
protectedRegionSlot → int?
The slot number to use for protected region handling.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingProfile → TrackingProfile?
The tracking profile to use (e.g., "balanced", "high_accuracy").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the options to a Map for communication over platform channels.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited