Poi constructor
Poi()
The Poi() constructor is initializing a new instance of the Poi class with the provided values
for its properties. The constructor takes in arguments for each property of the Poi class and
assigns them to the corresponding property using the this keyword. This allows you to create a
new Poi object and set its properties in a single line of code.
Implementation
Poi(
this.jsonData,
this.city,
this.idstore,
this.name,
this.date,
this.distance,
this.duration,
this.latitude,
this.locationid,
this.longitude,
this.zipcode,
this.radius,
this.address,
this.countrycode,
this.tags,
this.types,
this.contact,
this.openNow,
);