address property
String address; is declaring a property named address of type String in the Poi
class. This property will hold the address information of a Point of Interest (POI) object.
Implementation
String? address;
String address; is declaring a property named address of type String in the Poi
class. This property will hold the address information of a Point of Interest (POI) object.
String? address;