name property
String name; is declaring a property named name of type String in the Poi class.
This property will hold the name information of a Point of Interest (POI) object.
Implementation
String name;
String name; is declaring a property named name of type String in the Poi class.
This property will hold the name information of a Point of Interest (POI) object.
String name;