radius property
int radius; is declaring a property named radius of type int in the Poi class.
This property will hold the radius information of a Point of Interest (POI) object. The int type
indicates that the radius value will be an integer.
Implementation
int radius;