ProfileSource enum

The enum ProfileSource is defining a set of possible values for the source of a profile. It has two values: local and external. This enum can be used to represent the source of a profile in an application.

Inheritance
Available extensions

Values

local → const ProfileSource

In the enum ProfileSource, local, is defining one of the possible values for the source of a profile. It represents the profile source as "local".

external → const ProfileSource

In the enum ProfileSource, external; is defining one of the possible values for the source of a profile. It represents the profile source as "external".

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
The toString() method is overriding the default toString() method of the ProfileSource enum. It is used to convert the enum values into their corresponding string representations.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ProfileSource>
A constant List of the values in this enum, in order of their declaration.