watchRegion method
The function watchRegion() returns a Future that will resolve to a nullable String value.
@returns The method is returning a Future object that resolves to a String or null.
Implementation
Future<String?> watchRegion() {
return GeofencingFlutterPluginPlatform.instance.watchRegion();
}