registerBackgroundRegionCallback method
Persists the raw handles of the callback dispatcher and of the user
callback so the platform can wake them without a running Flutter engine.
@returns true when the handles have been persisted.
Implementation
@override
Future<bool> registerBackgroundRegionCallback(
int dispatcherHandle, int callbackHandle) async {
Map<String, dynamic> arguments = {
'dispatcherHandle': dispatcherHandle,
'callbackHandle': callbackHandle,
};
final returnVal = await methodChannel.invokeMethod<bool>(
'registerBackgroundRegionCallback', arguments);
return returnVal ?? false;
}