registerBackgroundRegionCallback method

Future<bool> registerBackgroundRegionCallback(
  1. int dispatcherHandle,
  2. int callbackHandle
)

Persists the raw handles of the callback dispatcher and of the user callback woken for region events while no Flutter engine is running.

Implementation

Future<bool> registerBackgroundRegionCallback(
    int dispatcherHandle, int callbackHandle) {
  throw UnimplementedError(
      'registerBackgroundRegionCallback() has not been implemented.');
}