eventProcessed constant
String
const eventProcessed
Sent to the platform once a region event has been handed to the callback, so it can release the resources held for that event.
Implementation
static const String eventProcessed = 'regionEventProcessed';